MCP API
=======

This section documents the Model Context Protocol (MCP) implementation, including server interfaces and session management.

.. autosummary::
   :toctree: _autosummary
   :recursive:
   
   agentle.mcp
   agentle.mcp.servers
   agentle.mcp.session_management

MCP Server Protocol
------------------

.. automodule:: agentle.mcp.servers.mcp_server_protocol
   :members:
   :undoc-members:
   :show-inheritance:

Streamable HTTP MCP Server
------------------------

.. automodule:: agentle.mcp.servers.streamable_http_mcp_server
   :members:
   :undoc-members:
   :show-inheritance:

Stdio MCP Server
--------------

.. automodule:: agentle.mcp.servers.stdio_mcp_server
   :members:
   :undoc-members:
   :show-inheritance:

Session Management
----------------

.. automodule:: agentle.mcp.session_management.session_manager
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: agentle.mcp.session_management.in_memory
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: agentle.mcp.session_management.redis
   :members:
   :undoc-members:
   :show-inheritance: 